==> vtigercrm-5.2.1p2.tgz: modules/Administration/language/hu_hu.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: E:\D_root\Dokumentumok\vtiger520\hungarian52\trunk\modules\Administration\language\hu_hu.lang.php - 18:10 2010.05.21. $
 * Description:  Defines the Hungarian language pack for the Administration module vtiger 5.2.0
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Istvan Holbok,  e-mail: holbok@gmail.com , mobil: +3670-3420900 , Skype: holboki
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_MODULE_NAME'=>'Adminisztráció',
'LBL_MODULE_TITLE'=>'Adminisztráció: Kezdőlap',

'LBL_NEW_FORM_TITLE'=>'Új Cég',
'ERR_DELETE_RECORD'=>"Adj meg egy rekord azonosítót a Cég törléséhez",
);

?>

==> vtigercrm-5.4.0.tgz: modules/Administration/language/hu_hu.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************
 * $Header: \modules\Administration\language\hu_hu.lang.php - 9:42 2011.11.11. $
 * Description:  Defines the Hungarian language pack for the Administration module vtiger 5.3.x
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Istvan Holbok,  e-mail: holbok@gmail.com , mobil: +3670-3420900 , Skype: holboki
 ********************************************************************************/
 
$mod_strings = array(
	'LBL_MODULE_NAME' => 'Adminisztráció',
	'LBL_MODULE_TITLE' => 'Adminisztráció: Kezdőlap',
	'LBL_NEW_FORM_TITLE' => 'Új Cég',
	'ERR_DELETE_RECORD' => 'Adj meg egy rekord azonosítót a Cég törléséhez'
);
?>
